tkmilan.var
===========

.. automodule:: tkmilan.var

   
   
   .. rubric:: Module Attributes

   .. autosummary::
   
      objT
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      Dict
      ObjectList
      StringList
      nothing
   
   

   
   
   



